@@ -133,7 +133,7 @@ class Route53RecoveryClusterClient(BaseClient):
     def update_routing_control_states(
         self,
         *,
-        UpdateRoutingControlStateEntries: Sequence["UpdateRoutingControlStateEntryTypeDef"],
+        UpdateRoutingControlStateEntries: Sequence[UpdateRoutingControlStateEntryTypeDef],
         SafetyRulesToOverride: Sequence[str] = ...
     ) -> Dict[str, Any]:
         """
